Index: trunk/src/includes/replies/functions.php
===================================================================
--- trunk/src/includes/replies/functions.php	(revision 5651)
+++ trunk/src/includes/replies/functions.php	(revision 5658)
@@ -102,5 +102,5 @@
  *                    the reply to id
  * @uses bbp_get_reply_url() To get the paginated url to the reply
  * @uses wp_safe_redirect() To redirect to the reply url
  * @uses bbPress::errors::get_error_message() To get the {@link WP_Error} error
  *                                              message
@@ -450,8 +450,5 @@
 
 		// Redirect back to new reply
-		wp_safe_redirect( $reply_url );
-
-		// For good measure
-		exit();
+		bbp_redirect( $reply_url );
 
 	/** Errors ****************************************************************/
@@ -492,5 +489,5 @@
  *                    and the reply to id
  * @uses bbp_get_reply_url() To get the paginated url to the reply
  * @uses wp_safe_redirect() To redirect to the reply url
  * @uses bbPress::errors::get_error_message() To get the {@link WP_Error} error
  *                                             message
@@ -762,8 +759,5 @@
 
 		// Redirect back to new reply
-		wp_safe_redirect( $reply_url );
-
-		// For good measure
-		exit();
+		bbp_redirect( $reply_url );
 
 	/** Errors ****************************************************************/
@@ -1274,5 +1268,5 @@
  *                    source topic ids and source topic's forum id
  * @uses bbp_get_topic_permalink() To get the topic permalink
  * @uses wp_safe_redirect() To redirect to the topic link
  */
 function bbp_move_reply_handler( $action = '' ) {
@@ -1497,8 +1491,5 @@
 
 	// Redirect back to the topic
-	wp_safe_redirect( bbp_get_topic_permalink( $destination_topic->ID ) );
-
-	// For good measure
-	exit();
+	bbp_redirect( bbp_get_topic_permalink( $destination_topic->ID ) );
 }
 
@@ -1570,5 +1561,5 @@
  * @uses bbp_get_reply_url() To get the reply url
  * @uses add_query_arg() To add custom args to the reply url
  * @uses wp_safe_redirect() To redirect to the reply
  * @uses bbPress::errors:add() To log the error messages
  */
@@ -1694,8 +1685,5 @@
 
 		// Redirect back to reply
-		wp_safe_redirect( $reply_url );
-
-		// For good measure
-		exit();
+		bbp_redirect( $reply_url );
 
 	// Handle errors
@@ -2311,5 +2299,5 @@
  * @uses current_user_can()
  * @uses bbp_get_topic_id()
- * @uses wp_safe_redirect()
+ * @uses bbp_redirect()
  * @uses bbp_get_topic_permalink()
  */
@@ -2317,12 +2305,11 @@
 
 	// Bail if not editing a topic
-	if ( !bbp_is_reply_edit() ) {
+	if ( ! bbp_is_reply_edit() ) {
 		return;
 	}
 
 	// User cannot edit topic, so redirect back to reply
-	if ( !current_user_can( 'edit_reply', bbp_get_reply_id() ) ) {
-		wp_safe_redirect( bbp_get_reply_url() );
-		exit();
+	if ( ! current_user_can( 'edit_reply', bbp_get_reply_id() ) ) {
+		bbp_redirect( bbp_get_reply_url() );
 	}
 }
@@ -102,5 +102,5 @@
  *                    the reply to id
  * @uses bbp_get_reply_url() To get the paginated url to the reply
- * @uses wp_safe_redirect() To redirect to the reply url
+ * @uses bbp_redirect() To redirect to the reply url
  * @uses bbPress::errors::get_error_message() To get the {@link WP_Error} error
  *                                              message
@@ -492,5 +489,5 @@
  *                    and the reply to id
  * @uses bbp_get_reply_url() To get the paginated url to the reply
- * @uses wp_safe_redirect() To redirect to the reply url
+ * @uses bbp_redirect() To redirect to the reply url
  * @uses bbPress::errors::get_error_message() To get the {@link WP_Error} error
  *                                             message
@@ -1274,5 +1268,5 @@
  *                    source topic ids and source topic's forum id
  * @uses bbp_get_topic_permalink() To get the topic permalink
- * @uses wp_safe_redirect() To redirect to the topic link
+ * @uses bbp_redirect() To redirect to the topic link
  */
 function bbp_move_reply_handler( $action = '' ) {
@@ -1570,5 +1561,5 @@
  * @uses bbp_get_reply_url() To get the reply url
  * @uses add_query_arg() To add custom args to the reply url
- * @uses wp_safe_redirect() To redirect to the reply
+ * @uses bbp_redirect() To redirect to the reply
  * @uses bbPress::errors:add() To log the error messages
  */
